@@ -623,7 +623,7 @@ void Request::post(bool authRequired) {
     case QVariant::String:
     case QVariant::ByteArray:
     case QVariant::Invalid:
-        data = d->data.toByteArray();
+        data = d->data.toString().toUtf8();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
@@ -670,7 +670,7 @@ void Request::put(bool authRequired) {
     case QVariant::String:
     case QVariant::ByteArray:
     case QVariant::Invalid:
-        data = d->data.toByteArray();
+        data = d->data.toString().toUtf8();
         break;
     default:
         data = QtJson::Json::serialize(d->data, ok);
