@@ -32,21 +32,6 @@ public:
         request(0)
     {
     }
-    
-    void setRoleNames(const QVariantMap &resource) {
-        roles.clear();        
-        int role = Qt::UserRole + 1;
-        
-        foreach (QString key, resource.uniqueKeys()) {
-            roles[role] = key.toUtf8();
-            role++;
-        }
-#if QT_VERSION < 0x050000
-        Q_Q(ResourcesModel);
-        
-        q->setRoleNames(roles);
-#endif
-    }
         
     void _q_onListRequestFinished() {
         if (!request) {
@@ -68,21 +53,21 @@ public:
                         setRoleNames(list.first().toMap());
                     }
                     
-                    q->beginInsertRows(QModelIndex(), items.size(), items.size() + list.size());
+                    q->beginInsertRows(QModelIndex(), items.size(), items.size() + list.size() - 1);
                     
                     foreach (QVariant item, list) {
                         items << item.toMap();
                     }
                     
                     q->endInsertRows();
-                    emit q->countChanged();
+                    emit q->countChanged(q->rowCount());
                 }
             }
         }
         
         ResourcesModel::disconnect(request, SIGNAL(finished()), q, SLOT(_q_onListRequestFinished()));
     
-        emit q->statusChanged();
+        emit q->statusChanged(request->status());
     }
     
     void _q_onInsertRequestFinished() {
@@ -96,16 +81,20 @@ public:
             QVariantMap result = request->result().toMap();
         
             if (!result.isEmpty()) {
+                if (items.isEmpty()) {
+                    setRoleNames(result);
+                }
+                
                 q->beginInsertRows(QModelIndex(), 0, 0);
                 items.prepend(result);
                 q->endInsertRows();
-                emit q->countChanged();
+                emit q->countChanged(q->rowCount());
             }
         }
         
         ResourcesModel::disconnect(request, SIGNAL(finished()), q, SLOT(_q_onInsertRequestFinished()));
     
-        emit q->statusChanged();
+        emit q->statusChanged(request->status());
     }
     
     void _q_onUpdateRequestFinished() {
@@ -134,7 +123,7 @@ public:
         
         ResourcesModel::disconnect(request, SIGNAL(finished()), q, SLOT(_q_onUpdateRequestFinished()));
     
-        emit q->statusChanged();
+        emit q->statusChanged(request->status());
     }
     
     void _q_onDeleteRequestFinished() {
@@ -151,7 +140,7 @@ public:
                     q->beginRemoveRows(QModelIndex(), i, i);
                     items.removeAt(i);
                     q->endRemoveRows();
-                    emit q->countChanged();
+                    emit q->countChanged(q->rowCount());
                     break;
                 }
             }
@@ -159,7 +148,7 @@ public:
         
         ResourcesModel::disconnect(request, SIGNAL(finished()), q, SLOT(_q_onDeleteRequestFinished()));
     
-        emit q->statusChanged();
+        emit q->statusChanged(request->status());
     }
     
     ResourcesRequest *request;
@@ -253,8 +242,8 @@ ResourcesModel::ResourcesModel(QObject *parent) :
     connect(d->request, SIGNAL(apiKeyChanged()), this, SIGNAL(apiKeyChanged()));
     connect(d->request, SIGNAL(clientIdChanged()), this, SIGNAL(clientIdChanged()));
     connect(d->request, SIGNAL(clientSecretChanged()), this, SIGNAL(clientSecretChanged()));
-    connect(d->request, SIGNAL(accessTokenChanged()), this, SIGNAL(accessTokenChanged()));
-    connect(d->request, SIGNAL(refreshTokenChanged()), this, SIGNAL(refreshTokenChanged()));
+    connect(d->request, SIGNAL(accessTokenChanged(QString)), this, SIGNAL(accessTokenChanged(QString)));
+    connect(d->request, SIGNAL(refreshTokenChanged(QString)), this, SIGNAL(refreshTokenChanged(QString)));
 }
 
 /*!
@@ -397,6 +386,18 @@ ResourcesRequest::Status ResourcesModel::status() const {
     return d->request->status();
 }
 
+/*!
+    \property QVariant ResourcesModel::result
+    \brief The current result of the model.
+    
+    \sa ResourcesRequest::result
+*/
+QVariant ResourcesModel::result() const {
+    Q_D(const ResourcesModel);
+    
+    return d->request->result();
+}
+
 /*!
     \property enum ResourcesModel::error
     \brief The error type of the model.
@@ -455,7 +456,7 @@ void ResourcesModel::fetchMore(const QModelIndex &) {
         
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onListRequestFinished()));
         d->request->list(d->resourcePath, d->part, d->filters, params);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -475,7 +476,7 @@ void ResourcesModel::list(const QString &resourcePath, const QStringList &part,
         d->params = params;
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onListRequestFinished()));
         d->request->list(d->resourcePath, d->part, d->filters, d->params);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -489,7 +490,7 @@ void ResourcesModel::insert(const QVariantMap &resource, const QStringList &part
         Q_D(ResourcesModel);
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onInsertRequestFinished()));
         d->request->insert(resource, d->resourcePath, part, params);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -504,7 +505,7 @@ void ResourcesModel::insert(int row, const QString &resourcePath, const QStringL
         d->writeResourcePath = resourcePath;
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onInsertRequestFinished()));
         d->request->insert(get(row), resourcePath, part, params);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -525,7 +526,7 @@ void ResourcesModel::update(int row, const QVariantMap &resource, const QStringL
                     
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onUpdateRequestFinished()));
         d->request->update(d->resourcePath, item, part);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -539,7 +540,7 @@ void ResourcesModel::del(int row) {
         d->writeResourcePath = d->resourcePath;
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onDeleteRequestFinished()));
         d->request->del(d->delId, d->resourcePath);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -553,7 +554,7 @@ void ResourcesModel::del(int row, const QString &resourcePath) {
         d->writeResourcePath = resourcePath;
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onDeleteRequestFinished()));
         d->request->del(d->delId, resourcePath);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
@@ -579,7 +580,7 @@ void ResourcesModel::reload() {
         clear();
         connect(d->request, SIGNAL(finished()), this, SLOT(_q_onListRequestFinished()));
         d->request->list(d->resourcePath, d->part, d->filters, d->params);
-        emit statusChanged();
+        emit statusChanged(d->request->status());
     }
 }
 
